@@ -15,8 +15,8 @@ eqtlDir.P <- function(genoGroups,gex,mc=mc,nper){
 
 	# And the three group comparison
 	} else if (PI==3){
-	  p1 <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)
-	  p2 <- gmw(gex[!is.na(genoGroups[,i])],createGroups(genoGroups[!is.na(genoGroups[,i]),i],c(2,1,0)),test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)
+	  p1 <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)$p.values
+	  p2 <- gmw(gex[!is.na(genoGroups[,i])],createGroups(genoGroups[!is.na(genoGroups[,i]),i],c(2,1,0)),test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)$p.values
 	  output[i] <- min(2*min(p1,p2),1)
 	  
 	}
